<template>
  <div
  class="gtn">
    <Section
    _backgroundColor="#FBF8E9">
      <SectionHeadline
      _text="Classy’s Live #GivingTuesdayNow Results" />
      
      <SectionDescription
      _text="Follow along in real time to see how the generosity of donors is powering 
      the Classy community. You’ll also learn how organizations across the United States 
      are fundraising and responding to the COVID-19 crisis."
      _subtext="All data is displayed according to [insert timezone] unless noted otherwise." />
    
      <StatsPrimary
      _value="$19,345,340" />
      
      <StatsCallout
      :_items="topCalloutStats" />
  
    </Section>
    
    <Section
    _backgroundColor="#FBF8E9">
      <SectionHeadline
      _text="#GivingTuesdayNow Campaigns Across the U.S." />
      
      <SectionDescription
      _text="Learn how organizations across the country are participating in 
      #GivingTuesdayNow and raising critical funds to keep their missions 
      moving forward during this challenging time. You may even be inspired 
      to give back to one of these awesome causes." />
  
    </Section>
    
    <Section
    _backgroundColor="#FBF8E9">
      <div class="row">
        <LeftRight>
          <template v-slot:left-side>
            <div
            style="padding-top: 90px">
              <SectionSubheadline
              _text="Donations in Real Time" />

              <StatsRealtime
              :_items="realtimeDonations" />
            </div>
          </template>

          <template v-slot:right-side>
            <ImageWithSquiggle
            :_image="helenWoodwardImage" />
          </template>
        </LeftRight>
      </div>
      
      <div
      class="row noMarginBottom">
        <div
        class="column">
          <SectionSubheadline
          _text="Donations by the Hour" />

          <SectionSubdescription
          _text="Time displayed according to browser time zone" />
        </div>
      </div>
      
      <div
      class="row"
      style="margin-top: 35px;">
        <div
        class="column">
          <StatsByHour
          :_items="hourlyStats" />

          <StatsCallout
          _noMargin="true"
          _title="Largest Online Donations"
          :_items="largestDonationStats" />
        </div>
      </div>
      
      <div
      class="row noMarginBottom">
        <div
        class="column">
          <SectionSubheadline
          _text="Top Causes by Amount Raised" />

          <SectionSubdescription
          _text="Only includes organizations with known NTEE codes in Classy's database." />
        </div>
      </div>
      
      <div
      class="row">
        <StatsStackedBar
        :_items="topCauses" />  
      </div>
    </Section>
    
    <Section
    _backgroundColor="#1B1542">
      <SectionHeadline
      _color="#fff"
      _text="Explore how the Classy community is responding to the COVID-19 crisis. " />
      
      <SectionDescription
      _color="#fff"
      _text="These organizations are raising critical funds for testing and 
      treatment, support for medical centers and staff, local training 
      and prevention measures, food distribution, and more. Learn how they’re 
      responding and how you can help. " />
      
      <HorizontalSliderDetailed
      :_items="sliderItems" />
    </Section>
    
    <Section>
      <SectionHeadline
      _text="Explore how the Classy community is responding to the COVID-19 crisis. " />
      
      <SectionDescription
      _small="true"
      _text="We launched our first-ever Classy Relief Fund to raise much-needed 
      support for nonprofits both in our hometown and across the nation.
      <br /><br />
      Our San Diego Relief Fund benefits several local nonprofits who are 
      working to improve the city in the wake of the coronavirus pandemic. 
      Our Classy National Relief Fund was launched with our partner 
      network to raise money for organizations across the country on the 
      front lines of COVID-19 relief. Check them out to find a nonprofit to 
      give back to." />
      
      <div class="row" style="margin: 68px 0 0 0;">
        <LeftRight>
          <template v-slot:left-side>
            <SectionSubheadline
            _text="Other Ways to Give Back" />

            <SectionSubdescription
            _text="There are other ways to support nonprofits and those in need. Here are a few things you can do to make an impact today and in the weeks to come:" />

            <BreakdownList
            :_items="giveBackItems" />
          </template>

          <template v-slot:right-side>
            <ImageWithSquiggle
            :_image="feedingSanDiegoImage" />
          </template>
        </LeftRight>
        <!--
        <div
        class="left">
          <SectionSubheadline
          _text="Other Ways to Give Back" />
          
          <SectionSubdescription
          _text="There are other ways to support nonprofits and those in need. Here are a few things you can do to make an impact today and in the weeks to come:" />

          <BreakdownList
          :_items="giveBackItems" />
        </div>

        <div
        class="right">
          <ImageWithSquiggle
          :_image="feedingSanDiegoImage" />
        </div>
        -->
      </div>
    </Section>      
  </div>
</template>

<script>
import Section from './section.vue';
import SectionHeadline from './section-headline.vue';
import SectionDescription from './section-description.vue';
import SectionSubheadline from './section-subheadline.vue';
import SectionSubdescription from './section-subdescription.vue';
import StatsPrimary from './stats-primary.vue';
import StatsCallout from './stats-callout.vue';
import StatsRealtime from './stats-realtime.vue';
import StatsByHour from './stats-by-hour.vue';
import StatsStackedBar from './stats-stacked-bar.vue';
import BreakdownList from './breakdown-list.vue';
import ImageWithSquiggle from './image-with-squiggle.vue';
import HorizontalSliderDetailed from './horizontal-slider-detailed.vue';
import LeftRight from './left-right.vue';

export default {
  props: [],

  components: {
    Section,
    SectionHeadline,
    SectionDescription,
    SectionSubheadline,
    SectionSubdescription,
    StatsPrimary,
    StatsCallout,
    StatsRealtime,
    StatsByHour,
    StatsStackedBar,
    BreakdownList,
    ImageWithSquiggle,
    HorizontalSliderDetailed,
    LeftRight,
  },
  
	data () {
		return {
      topCalloutStats: [
        {
          title: 'Active<br>Campaigns',
          value: '1,234',
        },
        {
          title: 'Amount Raised for COVID-19 Direct Response Campaigns',
          value: '$1,234',
        },
        {
          title: 'Active COVID-19 Direct Response Campaigns',
          value: '1,234',
        },
      ],
      
      realtimeDonations: [
        {
          headline: 'Chula Vista, CA',
          subheadline: 'Just Now',
          text: 'A lovely human just made a donation',
        },
        {
          headline: 'Chula Vista, CA',
          subheadline: 'Just Now',
          text: 'A lovely human just made a donation',
        },
        {
          headline: 'Chula Vista, CA',
          subheadline: 'Just Now',
          text: 'A lovely human just made a donation',
        },
      ],
      
      helenWoodwardImage: 'https://cdn.glitch.com/2297ee47-b937-497b-94e1-16568ac3b6ff%2Fhelen-woodward.png?v=1588216767090',
      feedingSanDiegoImage: 'https://cdn.glitch.com/2297ee47-b937-497b-94e1-16568ac3b6ff%2Ffeeding-san-diego.png?v=1588271386593',
      
      hourlyStats: [
        {
          value: 0,
        },
        
        {
          value: 0,
        },
        
        {
          value: 200,
        },
        
        {
          value: 400,
        },
        
        {
          value: 400,
        },
        
        {
          value: 400,
        },
        
        {
          value: 400,
        },
        
        {
          value: 400,
        },
        
        {
          value: 400,
        },
        
        {
          value: 400,
        },
        
        {
          value: 400,
        },
        
        {
          value: 400,
        },
        
        {
          value: 400,
        },
        
        {
          value: 400,
        },
        
        {
          value: 400,
        },
        
        {
          value: 400,
        },
        
        {
          value: 400,
        },
        
        {
          value: 400,
        },
        
        {
          value: 400,
        },
        
        {
          value: 400,
        },
        
        {
          value: 400,
        },
        
        {
          value: 400,
        },
        
        {
          value: 400,
        },
        
        {
          value: 400,
        },
        
        {
          value: 400,
        },
      ],
      
      largestDonationStats: [
        {
          caption: 'A generous human from <b>[city, country]</b> just made a donation.',
          value: '$35,000',
        },
        {
          caption: 'A generous human from <b>[city, country]</b> just made a donation.',
          value: '$35,000',
        },
        {
          caption: 'A generous human from <b>[city, country]</b> just made a donation.',
          value: '$35,000',
        },
      ],
      
      topCauses: [
        {
          label: 'Human Services',
          value: '$1,000,000.00', 
        },
        
        {
          label: 'Health',
          value: '$50,000', 
        },
      ],
      
      sliderItems: [
        {
          image: 'https://cdn.glitch.com/2297ee47-b937-497b-94e1-16568ac3b6ff%2Fslider-1.jpg?v=1588267505898',
          headline: 'The Greater Boston Food Bank',
          text: 'As the coronavirus poses an even greater threat to food insecure populations, the Greater Boston Food Bank is raising money to ensure their food distribution continues to serve those in need.',
          linkText: 'View Campaign',
          linkHref: 'https://classy.org/blog',
        },
        
        {
          image: 'https://cdn.glitch.com/2297ee47-b937-497b-94e1-16568ac3b6ff%2Fslider-2.jpg?v=1588267505444',
          headline: 'Broadway Cares',
          text: 'Broadway Cares launched its COVID-19 Emergency Assistance Fund to help entertainment professionals meet coronavirus-related expenses and other challenges brought about by the evolving pandemic. Over 20 Broadway producers joined together to match every donation up to $1 million.',
          linkText: 'View Campaign',
          linkHref: 'https://classy.org/blog',
        },
        
        {
          image: 'https://cdn.glitch.com/2297ee47-b937-497b-94e1-16568ac3b6ff%2Fslider-3.jpg?v=1588267504213',
          headline: 'Cedars Sinai',
          text: 'Like many nonprofits in the healthcare industry, Cedars Sinai is asking for support from its community to help fund staff training, critical research, day-to-day operations, and other necessities during the COVID-19 pandemic.',
          linkText: 'View Campaign',
          linkHref: 'https://classy.org/blog',
        },
      ],
      
      giveBackItems: [
        'Visit VolunteerMatch to find volunteer information and listings in your local community',
        'Corporations can donate medical equipment or supplies through FEMA',
        'Post and share stories about how nonprofits are responding––use the hashtag #GivingTuesdayNow and tag @Classy for a chance to be featured on our social media channels',
        'Offer up your expertise and give pro bono hours to a nonprofit',
      ],
    };
	},
}
</script>

<style>
  .gtn .row {
    display: flex;
    flex-direction: row;
    margin-bottom: 100px;
  }
  
  .gtn .row.noMarginBottom {
    margin-bottom: 0;
  }
  
  .gtn .column {
    display: flex;
    flex-direction: column;
    width: 100%;
  }
  
  .gtn .left {
    width: 40%;
    margin-right: auto;
    padding-right: 70px;
  }
  
  .gtn .right {
    width: 60%;
    margin-left: auto;
  }
</style>